| SOTUcorpus | R Documentation |
Texts from the Presidential State of the Union addresses from 1790 to 2019
data(SOTUcorpus)
A document corpus with elements documents, metadata, settings and tokens. The documents data frame has the following variables.
The text of the speeches
First name of the president.
President's last name
Date of delivery.
Type of delivery: spoken or written
Type of speech: SOTY or other
President's party: Democratic, Democratic-Republican, Federalist, Independent, Republican, Whig
Document identifier
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.