| denmarkEES2009 | R Documentation |
The full set of respondents from Denmark for the 2009 European Election Survey.
data(denmarkEES2009)
A data frame with 1000 observations on the following 272 variables.
t001Study ID
t002File Version
t100Respondent ID
t101Country code
t102Country
t103Political system (as T102, except for Belgium)
t104Region (country code)
t105Size of Locality (country code)
t106Belgium: 3 regions
t107Interview language
t200Interview mode
t201Interviewer ID
t201aInterviewer gender
t201bInterviewer year of birth
t201cInterviewer nationality
t201dInterviewer native language
t201eInterviewer years of experience
t203number of calls before start of succesful interview
t204R in callback group for Q26b (Ireland only)
t300Interview date: year
t301Interview date: month
t302Interview date: day
t303Interview start: hour
t304Interview start: minute
t305Interview end: hour
t306Interview end: minute
t307Interview length (minutes)
t400Household size (over 15 year old)
t401Fixed line in household?
t402Own mobile phone?
q1most important problem in [country] today
q2second most important problem in [country] today
q3third most important problem in [country] today
q4political party best to deal with [1st] MIP
q5Admin. level dealing with MIP?
q6Admin. level that should deal with MIP?
q7days a week follow news
q8_adays a week watch news programme A
q8_bdays a week watch news programme B
q8_cdays a week watch news programme C
q8_ddays a week watch news programme D
q9Watch news on other channel more often?
q10_1which other news channel 1st
q10_O1which other news channel 1st [open answer]
q10_2which other news channel 2nd
q10_O2which other news channel 2nd [open answer]
q10_3which other news channel 3rd
q10_O3which other news channel 3rd [open answer]
q10_4which other news channel 4th
q10_O4which other news channel 4th [open answer]
q10_5which other news channel 5th
q10_O5which other news channel 5th [open answer]
q11adays a week watch other channel 1st
q11bdays a week watch other channel 2nd
q11cdays a week watch other channel 3rd
q11ddays a week watch other channel 4th
q11edays a week watch other channel 5th
q12_adays a week read newspaper A
q12_bdays a week read newspaper B
q12_cdays a week read newspaper C
q13Read other paper more frequently?
q14_1which other newspaper 1st
q14_O1which other newspaper 1st [open answer]
q14_2which other newspaper 2nd
q14_O2which other newspaper 2nd [open answer]
q14_3which other newspaper 3rd
q14_O3which other newspaper 3rd [open answer]
q14_4which other newspaper 4th
q14_O4which other newspaper 4th [open answer]
q14_5which other newspaper 5th
q14_O5which other newspaper 5th [open answer]
q15adays a week read other paper 1st
q15bdays a week read other paper 2nd
q15cdays a week read other paper 3rd
q15ddays a week read other paper 4th
q15edays a week read other paper 5th
q16how often watch program about election on TV?
q17how often read about election in newspaper?
q18how often talk to friends/family about election?
q19how often attend public meeting/rally about election?
q20how often look into website concerned with election?
q21contacted in campaign
q21_acontacted in campaign by party/candidate: email
q21_bcontacted in campaign by party/candidate: internet networking
q21_ccontacted in campaign by party/candidate: phone
q21_dcontacted in campaign by party/candidate: direct mail
q21_econtacted in campaign by party/candidate: flyer through post
q21_fcontacted in campaign by party/candidate: face to face [at doorstep]
q21_gcontacted in campaign by party/candidate: face to face [in street]
q21_hcontacted in campaign by party/candidate: other personal contact
q21_icontacted in campaign by party/candidate: never been contacted - France on
q22visited [which] 'how to vote' website?
q22b_O1name 'how to vote' website: other 1
q22b_O2name 'how to vote' website: other 2
q22b_O3name 'how to vote' website: other 3
q22b_O4name 'how to vote' website: other 4
q22b_O5name 'how to vote' website: other 5
q23Interest in EP election campaign
q24Did or did not vote in EP elections
q25Which party voted for in EP elections
q26Which party, if R had voted in EP elections
q26bWhich party voted for in local elections [BE & IE only]
q27Actual vote in last general election
q28Vote intention in general elections
q29Responsibility of government for economic conditions
q30Responsibility of EU for economic conditions
q31Responsibility of government for standards of health care
q32Responsibility of EU for standards of health care
q33Responsibility of government for levels of immigration
q34Responsibility of EU for levels of immigration
q35Responsibility of government for setting interest rates
q36Responsibility of EU for setting interest rates
q37Responsibility of government for dealing with climate change
q38Responsibility of EU for dealing with climate change
t501Rotation indicator Q39: which party probed first
q39_p1Propensity to vote for Party 1
q39_p2Propensity to vote for Party 2
q39_p3Propensity to vote for Party 3
q39_p4Propensity to vote for Party 4
q39_p5Propensity to vote for Party 5
q39_p6Propensity to vote for Party 6
q39_p7Propensity to vote for Party 7
q39_p8Propensity to vote for Party 8
q39_p9Propensity to vote for Party 9
q39_p10Propensity to vote for Party 10
q39_p11Propensity to vote for Party 11
q39_p12Propensity to vote for Party 12
q39_p13Propensity to vote for Party 13
q39_p14Propensity to vote for Party 14
q39_p15Propensity to vote for Party 15
q40agree/disagree: EU Parliament considers concerns of EU citizens
q41agree/disgree: You trust the institutions of the European Union
q42agree/disgaree: very important which candidates win seats in EP elections
q43agree/disgaree: very important which party wins most seats EP elections
q44agree/disagree: [country] Parliament considers concerns of [country] citizen
q45q45|agree/disgaree: very important which party wins most seats NP elections
q46q46| Left-right self-placement
t502Rotation indicator Q47: which party probed first
q47_p1left-right-placement: party 1
q47_p2left-right-placement: party 2
q47_p3left-right-placement: party 3
q47_p4left-right-placement: party 4
q47_p5left-right-placement: party 5
q47_p6left-right-placement: party 6
q47_p7left-right-placement: party 7
q47_p8left-right-placement: party 8
q47_p9left-right-placement: party 9
q47_p10left-right-placement: party 10
q47_p11left-right-placement: party 11
q47_p12left-right-placement: party 12
q47_p13left-right-placement: party 13
q47_p14left-right-placement: party 14
q47_p15left-right-placement: party 15
q48retrospective sociotropic economic evaluation
q49prospective sociotropic economic evaluation
q50Retrospective perception of changes in standards of health care
q51Retrospective perception of changes in levels of immigration
q52Evaluation of changes in levels of immigration
q53Retrospective perception of changes in interest rates
q54Evaluation of changes in interest rates
q55Retrospective perception of changes in climate change
t503Rotation indicator Q56-Q67: which question posed first
q56agree/disagree: Immigrants required to adapt to customs of [country]
q57agree/disagree: Private enterprise best to solve [country's] economic proble
q58agree/disagree: Same-sex marriages should be prohibited by law
q59agree/disagree: public services and industries should be in state ownership
q60agree/disagree: Women should be free to decide on matters of abortion
q61agree/disagree: Politics should abstain from intervening in the economy
q62agree/disagree: People who break law should get much harsher sentences than
q63agree/disagree: Income and wealth should be redistributed towards ordinary p
q64agree/disagree: Schools must teach children to obey authority
q65agree/disagree: EU treaty changes should be decided by referendum
q66agree/disagree: A woman should cut down on paid work for her family
q67agree/disagree: Immigration to [country] should be decreased significantly
q68Impact of government policies on economic conditions
q69Impact of government policies on standards of health care
q70Impact of government policies on levels of immigration
q71Impact of government policies on interest rates
q72Impact of government policies on climate change
q73Impact of EU policies on economic conditions
q74Impact of EU policies on standards of health care
q75Impact of EU policies on levels of immigration
q76Impact of EU policies on interest rates
q77Impact of EU policies on climate change
q78interest in politics
q79EU membership good or bad
q80respondent's attitude to European unification
t504Rotation indicator Q81: which party probed first
q81_p1european unification: perception of party 1
q81_p2european unification: perception of party 2
q81_p3european unification: perception of party 3
q81_p4european unification: perception of party 4
q81_p5european unification: perception of party 5
q81_p6european unification: perception of party 6
q81_p7european unification: perception of party 7
q81_p8european unification: perception of party 8
q81_p9european unification: perception of party 9
q81_p10european unification: perception of party 10
q81_p11european unification: perception of party 11
q81_p12european unification: perception of party 12
q81_p13european unification: perception of party 13
q81_p14european unification: perception of party 14
q81_p15european unification: perception of party 15
q82_1see self as [country] citizen, or [country region/ethnic] citizen?
q82not only [country] citizen, but also european citizen?
q83EU enlargment good or bad
q84satisfaction with democracy in [country]
q85satisfaction with democracy in EU
q86approval of [country] government's record
q87close to a party [pid]
q88close or sympathizer
q89not close to a party - but closer to a party?
q90not close but closer to party: which?
q91confidence: EU decisions in the interest of [country]
t505Rotation indicator Q92-Q98: which question posed first
q92Switzerland is a member of the EU - T/F
q93EU has 25 member states - T/F
q94Every EU country elects same number of MEPs - T/F
q95Every six months, a different country presides the Council - T/F
q96Country specific knowledge question 1 - T/F
q97Country specific knowledge question 2 - T/F
q98Country specific knowledge question 3 - T/F
q99trade union: R or anyone in household member
q100age when stopped full-time education
q101education: highest level completed
q101_O1education: highest level completed: other
q101beducation, vocational: highest level completed (DK & DE only)
Q101B_O1education, vocational: highest level completed: other (DK & DE only)
q102gender
q103year of birth
q104both parents born in [country]?
q105which country mother born
q105_O1which country mother born: other
q106which country father born
q106_O1which country father born: other
q107in which country R born
q107_O1in which country R born: other
q108consider self [nationality] or belong to other group - or both
q108_O1consider self belong only to other group: which
q108_O2consider self belong also to other group: which
q109marital status
q110work situation
q111sector of employment
q113occupation
q114social class (subjective)
q115rural-urban area
q116years residency in current community
q117religion
q117_O1religion: other
q118attendance at religious services
q119subjective religiosity
q120subjective standard of living
v100sample weight per country (calibrated)
v111selection probability per country: EU-27
v112selection probability per country: EU-25
v113selection probability per country: EU-15
v114selection probability per country: EU-12
v115selection probability per country: EU-10
v116selection probability per country: EU-9
v117selection probability per country: EU-6
v121inverse selection probability per country: EU-27
v122inverse selection probability per country: EU-25
v123inverse selection probability per country: EU-15
v124inverse selection probability per country: EU-12
v125inverse selection probability per country: EU-10
v126inverse selection probability per country: EU-9
v127inverse selection probability per country: EU-6
v131political weight
v132political weight actual EP voters only
v200education: ISCED level (cross-country comparable)
v301Strength of closeness to Party
v302Direction of closeness to Party
https://dbk.gesis.org/dbksearch/sdesc2.asp?no=5055&db=e&doi=10.4232/1.11760
Egmond, Marcel van; Brug, Wouter van der; Hobolt, Sara; Franklin, Mark; Sapir, Eliyahu V. (2013): European Parliament Election Study 2009, Voter Study. GESIS Data Archive, Cologne. ZA5055 Data file Version 1.1.0, doi:10.4232/1.11760
data(denmarkEES2009)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.